.. image:: logo-500px.png
   :alt: histbook
   :target: https://github.com/scikit-hep/histbook
   :align: center

|

histbook
========

.. include:: ../../README.rst
  :start-after: inclusion-marker-1-do-not-remove
  :end-before:  inclusion-marker-3-do-not-remove

Tutorial
--------

See the `project homepage <https://github.com/scikit-hep/histbook>`__ for a `tutorial <https://github.com/scikit-hep/histbook#tutorial>`__.

Interactive tutorial
--------------------

Run `this tutorial <https://mybinder.org/v2/gh/scikit-hep/histbook/master?filepath=binder%2Ftutorial.ipynb>`__ on Binder.

Reference documentation
-----------------------

.. toctree::
   :maxdepth: 1

   histograms
   books-of-histograms
   axis-descriptors
   plotting
